@@ -1,6 +1,6 @@
 use afire::{Header, Method, Query, Response, Server};
 
-// Send data to server with a Query String and Form Data
+// Send data to server with a Query String, Path Prams and Form Data
 
 fn main() {
     // Create a new Server instance on localhost port 8080
@@ -18,7 +18,10 @@ fn main() {
                 .unwrap_or_else(|| "Nobody".to_string())
         );
 
-        Response::new(200, &text, vec![Header::new("Content-Type", "text/html")])
+        Response::new()
+            .status(200)
+            .text(text)
+            .header(Header::new("Content-Type", "text/html"))
     });
 
     // Define another route
@@ -28,14 +31,17 @@ fn main() {
         // Instead it is part of the req.body but as a string
         // We will need to parse it get it as a query
         // This is *super* easy to do with afire
-        let body_data = Query::from_body(req.body);
+        let body_data = Query::from_body(String::from_utf8(req.body).unwrap()).unwrap();
 
         let name = body_data
             .get("name")
             .unwrap_or_else(|| "Nobody".to_string());
         let text = format!("<h1>Hello, {}</h1>", name);
 
-        Response::new(200, &text, vec![Header::new("Content-Type", "text/html")])
+        Response::new()
+            .status(200)
+            .text(text)
+            .header(Header::new("Content-Type", "text/html"))
     });
 
     // Define webpage with form
@@ -47,11 +53,38 @@ fn main() {
             <input type="submit" value="Submit">
       </form>"#;
 
-        Response::new(200, page, vec![Header::new("Content-Type", "text/html")])
+        Response::new()
+            .status(200)
+            .text(page)
+            .header(Header::new("Content-Type", "text/html"))
     });
 
+    // Define a page with path params
+    // As this is not built into afire you will need to use middleware (for now :P)
+    // This is like "/greet/:name"
+    server.middleware(Box::new(|req| {
+        // Move on if path dosent start with /path or the method is not get
+        // You could also do this with a regex (but afire is dependency free so I wont show that in this example)
+        if !req.path.starts_with("/greet/") || req.method != Method::GET {
+            return None;
+        }
+
+        // Extract the pram value
+        // This is getting the 2rd path value
+        // Ex: /greet/Darren/
+        let name = req.path.split("/").nth(2).unwrap();
+
+        // Respond with "Hello, {{NAME}}"
+        Some(
+            Response::new()
+                .text(format!("<h1>Hello, {}</h1>", name))
+                .header(Header::new("Content-Type", "text/html")),
+        )
+    }));
+
     // You can now goto http://localhost:8080?name=John and should see "Hello, John"
     // If you goto http://localhost:8080/form and submit the form you should see "Hello, {NAME}"
+    // Also goto http://localhost:8080/greet/John and you should see "Hello, John"
 
     println!(
         "[04] Listening on http://{}:{}",
