@@ -23,19 +23,22 @@ fn main() {
         }
         html.push_str("</table>");
 
-        Response::new(200, &html, vec![Header::new("Content-Type", "text/html")])
+        Response::new()
+            .status(200)
+            .text(html)
+            .header(Header::new("Content-Type", "text/html"))
     });
 
     // Set a cookie defined in the Query
     server.route(Method::GET, "/set", |req| {
         // Create a new cookie
         let cookie = SetCookie::new(
-            &req.query.get("name").unwrap_or_else(|| "test".to_string()),
-            &req.query.get("value").unwrap_or_else(|| "test".to_string()),
+            req.query.get("name").unwrap_or_else(|| "test".to_string()),
+            req.query.get("value").unwrap_or_else(|| "test".to_string()),
         )
         // Set some options
-        .set_max_age(60 * 60)
-        .set_path("/");
+        .max_age(60 * 60)
+        .path("/");
 
         let body = format!(
             "Set Cookie '{}' to '{}'",
@@ -43,7 +46,11 @@ fn main() {
         );
 
         // Set the cookie
-        Response::new(200, &body, vec![Header::new("Content-Type", "text/html")]).add_cookie(cookie)
+        Response::new()
+            .status(200)
+            .text(body)
+            .header(Header::new("Content-Type", "text/html"))
+            .cookie(cookie)
     });
 
     // Now goto http://localhost:8080/set?name=hello&value=world
